<?php

namespace Drupal\taas\DependencyInjection\Compiler;

use Symfony\Component\DependencyInjection\Compiler\CompilerPassInterface;
use Symfony\Component\DependencyInjection\ContainerBuilder;

/**
 * Defines a compiler pass that processes token services.
 */
final class TokenPass implements CompilerPassInterface {

  /**
   * Processes the container to find and organize token services.
   *
   * @param \Symfony\Component\DependencyInjection\ContainerBuilder $container
   *   The container builder.
   */
  public function process(ContainerBuilder $container): void {
    $token_definitions = array_filter(
      $container->findTaggedServiceIds('taas.token'),
      function(array $tags): bool {
        foreach ($tags as $tag) {
          if (isset($tag['token'])) {
            return TRUE;
          }
        }

        return FALSE;
      }
    );

    $tokens = [];
    foreach ($token_definitions as $id => $tags) {
      foreach ($tags as $tag) {
        $tag_type = $tag['type'];
        $tag_token = $tag['token'];
        $tag_title = $tag['title'];

        $tokens[$tag_type][$tag_token] = [
          'id' => $id,
          'title' => $tag_title,
        ];
      }
    }

    $container
      ->getDefinition('taas.resolver.token')
      ->addArgument($tokens);
  }

}
